# -*- coding: utf-8 -*-
from plone.app.testing.bbb_at import PloneTestCase
from Products.CMFCore.utils import getToolByName


class TestBaseProfile(PloneTestCase):

    def afterSetUp(self):
        self.loginAsPortalOwner()
        from Products.CMFPlone.utils import get_installer
        qi = get_installer(self.portal)
        qi.uninstall_product('Products.ATContentTypes')
        portal_setup = self.portal.portal_setup
        # It looks like the hiddenprofile utility from CMFPlone is not loaded
        # in these tests.  So our default profile is installed, instead of only
        # our base profile.  This explains why our portal_types are available
        # at all.  This means we need to manually apply the fullinstall
        # profile.
        portal_setup.runAllImportStepsFromProfile(
            'Products.ATContentTypes:fulluninstall')
        # Now we apply the base profile.
        portal_setup.runAllImportStepsFromProfile(
            'profile-Products.ATContentTypes:base')

    def test_attypes_not_installed(self):
        tt = getToolByName(self.portal, 'portal_types')
        types = tt.listTypeInfo()
        for t in types:
            self.assertNotEqual(t.product, 'ATContentTypes')



## Script (Python) "isExpired"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=content=None
##title=Find out if the object is expired

from Products.CMFPlone.utils import isExpired

if not content:
    content = context

return isExpired(content)



## Script (Python) "getObjSize"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=obj=None, size=None
##title=

from Products.CMFPlone.utils import base_hasattr
from Products.CMFPlone.utils import human_readable_size

if obj is None:
    obj = context

# allow arbitrary sizes to be passed through,
# if there is no size, but there is an object
# look up the object, this maintains backwards
# compatibility
if size is None and base_hasattr(obj, 'get_size'):
    size = obj.get_size()

return human_readable_size(size)
